pub struct Glyph {
pub ch: char,
pub fg: Color,
pub bg: Color,
}Expand description
A posterized pixel block: the best-matching glyph plus its foreground and background colors.
The background color is only meaningful for glyphs that don’t cover the full cell (anything
but ' ' and '█'); the foreground color is only meaningful for glyphs other than ' '.
Both are still populated for those edge cases (as the block’s overall average color) so a
caller never has to special-case Glyph before styling a cell with it.
Fields
ch: charThe selected block-element/quadrant/sextant character.
fg: ColorThe color assigned to the “on” pixels (those set in the glyph’s bit pattern).
bg: ColorThe color assigned to the “off” pixels (those clear in the glyph’s bit pattern).